Enum allocators::AllocatorError
[−]
[src]
pub enum AllocatorError {
OutOfMemory,
AllocatorSpecific(String),
}Errors that can occur while creating an allocator or allocating from it.
Variants
OutOfMemoryThe allocator failed to allocate the amount of memory requested of it.
AllocatorSpecific(String)An allocator-specific error message.