Struct allocators::composable::Fallback
[−]
[src]
pub struct Fallback<M: BlockOwner, F: BlockOwner> { // some fields omitted }
This allocator has a main and a fallback allocator. It will always attempt to allocate first with the main allocator, and second with the fallback.
Methods
impl<M: BlockOwner, F: BlockOwner> Fallback<M, F>[src]
fn new(main: M, fallback: F) -> Self
Create a new Fallback